@@ -57,6 +57,9 @@ class Insert:
 
     :param code: a :class:`purdy.content.Code` object containing the source
                  code to insert.
+
+    :param pauses: optional list of :class:`purdy.actions.Pause` objects that
+                   specify where to insert pauses in the output
     """
     def __init__(self, code_box, position, code, pauses=[]):
         self.code_box = code_box
@@ -108,6 +111,9 @@ class Append(Insert):
 
     :param code: a :class:`purdy.content.Code` object containing the source
                  code to insert.
+
+    :param pauses: optional list of :class:`purdy.actions.Pause` objects that
+                   specify where to insert pauses in the output
     """
     def __init__(self, code_box, code, pauses=[]):
         super().__init__(code_box, 0, code, pauses)
@@ -355,6 +361,9 @@ class AppendTypewriter(TypewriterStep):
 
     :param code: a :class:`purdy.content.Code` object containing the source
                  code to insert.
+
+    :param pauses: optional list of :class:`purdy.actions.Pause` objects that
+                   specify where to insert pauses in the output
     """
 
     def __init__(self, code_box, code, pauses=[]):
@@ -379,6 +388,9 @@ class InsertTypewriter(TypewriterStep):
 
     :param code: a :class:`purdy.content.Code` object containing the source
                  code to insert.
+
+    :param pauses: optional list of :class:`purdy.actions.Pause` objects that
+                   specify where to insert pauses in the output
     """
     def __init__(self, code_box, position, code, pauses=[]):
         if position < 0:
@@ -430,6 +442,52 @@ class SuffixTypewriter(TypewriterBase):
 
         return steps
 
+
+class AppendPrompt(TypewriterBase):
+    """This action is used to show a prompt and its response. It appends the
+    content of a :class:`purdy.content.Code` object to a
+    :class:`purdy.ui.CodeBox` as a prompt, waits for the 'right arrow' key,
+    then uses the typewriter animation to add the response to the same line.
+
+    :param code_box: the :class:`purdy.ui.CodeBox` instance to append code
+                     into
+
+    :param code: a :class:`purdy.content.Code` object containing the prompt
+                 code to insert.
+
+    :param response: text to place after the prompt
+    """
+    def __init__(self, code_box, code, response):
+        self.code_box = code_box
+        self.code = code
+        self.response = response
+        self.pauses = []
+
+    def __str__(self):
+        prompt = condense(self.code.source)
+        response = condense(self.response)
+
+        return f'actions.AppendPrompt({prompt}, {response}")'
+
+    def steps(self):
+        # Insert the prompt, then wait
+        lines = parse_source(self.code.source, self.code.lexer)
+        steps = [steplib.InsertRows(self.code_box, 0, lines), ]
+        steps.append(steplib.CellEnd())
+
+        # Insert the response
+        for count, letter in enumerate(self.response):
+            cursor = False
+            if count + 1 != len(self.response):
+                cursor = True
+
+            steps.extend([
+                steplib.SuffixRow(self.code_box, -1, letter, cursor),
+                steplib.Sleep(self.delay_until_next_letter),
+            ])
+
+        return steps
+
 # =============================================================================
 # Presentation Actions
 # =============================================================================
