@@ -179,7 +179,7 @@ class SuffixRow(BaseEditStep):
         return inside
 
     def render_step(self):
-        line = deepcopy(self.code_box.listing.lines[self.position - 1])
+        line = deepcopy(self.code_box.listing.get_line(self.position))
         self.undo_line = line
 
         token = line.parts[-1][0]
